@@ -1,7 +1,7 @@
 use warnings;
 use strict;
 
-our $VERSION = '0.3';
+our $VERSION = '0.32';
 
 =head1 NAME
 
@@ -297,8 +297,7 @@ sub scalarp ($) {
 =head1 Data::SExpression::Parser callbacks
 
 These are for internal use only, and are used to generate the data
-structures returned by L</read>. These are intended for internal use
-only.
+structures returned by L</read>. 
 
 =head2 new_cons CAR CDR
 
@@ -350,6 +349,13 @@ sub new_string {
     return $content;
 }
 
+=head1 BUGS
+
+None known, but there are probably a few. Please reports bugs via
+rt.cpan.org by sending mail to:
+
+L<bug-Data-SExpression@rt.cpan.org>
+
 
 =head1 AUTHOR
 
